@@ -126,8 +126,8 @@ describe Braintree::PaymentMethod do
       expect(apple_pay_card.bin).not_to be_nil
       expect(apple_pay_card.token).to eq(token)
       expect(apple_pay_card.card_type).to eq(Braintree::ApplePayCard::CardType::Visa)
-      expect(apple_pay_card.payment_instrument_name).to eq("Visa 8886")
-      expect(apple_pay_card.source_description).to eq("Visa 8886")
+      expect(apple_pay_card.payment_instrument_name).to eq("Visa 2006")
+      expect(apple_pay_card.source_description).to eq("Visa 2006")
       expect(apple_pay_card.default).to eq(true)
       expect(apple_pay_card.image_url).to match(/apple_pay/)
       expect(apple_pay_card.expiration_month.to_i).to be > 0
@@ -671,6 +671,30 @@ describe Braintree::PaymentMethod do
       end
     end
 
+      it "includes ani response when account information inquiry is sent in options" do
+          customer = Braintree::Customer.create!
+          nonce = nonce_for_new_payment_method(
+            :credit_card => {
+              :cvv => "123",
+              :number => Braintree::Test::CreditCardNumbers::Visa,
+              :expiration_date => "05/2029",
+            },
+          )
+          result = Braintree::PaymentMethod.create(
+            :payment_method_nonce => nonce,
+            :customer_id => customer.id,
+            :options => {
+              :verify_card => true,
+              :account_information_inquiry => "send_data",
+            },
+          )
+
+          expect(result).to be_success
+          verification = result.payment_method.verification
+          expect(verification.ani_first_name_response_code).not_to be_nil
+          expect(verification.ani_last_name_response_code).not_to be_nil
+      end
+
     context "account_type" do
       it "verifies card with account_type debit" do
         nonce = nonce_for_new_payment_method(
@@ -1228,7 +1252,7 @@ describe Braintree::PaymentMethod do
         expect(apple_pay_card.image_url).to match(/apple_pay/)
         expect(apple_pay_card.expiration_month.to_i).to be > 0
         expect(apple_pay_card.expiration_year.to_i).to be > 0
-        expect(apple_pay_card.source_description).to eq("Visa 8886")
+        expect(apple_pay_card.source_description).to eq("Visa 2006")
         expect(apple_pay_card.customer_id).to eq(customer.id)
         apple_pay_card.merchant_token_identifier == "DNITHE302308980427388297"
         apple_pay_card.source_card_last4 == "2006"
@@ -1588,6 +1612,29 @@ describe Braintree::PaymentMethod do
         end
       end
 
+      it "includes ani response after updating the options with account information inquiry" do
+        customer = Braintree::Customer.create!
+        credit_card = Braintree::CreditCard.create!(
+          :customer_id => customer.id,
+          :cvv => "123",
+          :number => Braintree::Test::CreditCardNumbers::Visa,
+          :expiration_date => "05/2032",
+        )
+        update_result = Braintree::PaymentMethod.update(
+          credit_card.token,
+          :options => {
+            :verify_card => true,
+            :account_information_inquiry => "send_data",
+          },
+        )
+
+        expect(update_result).to be_success
+        verification = update_result.payment_method.verification
+        expect(verification.ani_first_name_response_code).not_to be_nil
+        expect(verification.ani_last_name_response_code).not_to be_nil
+      end
+
+
       context "verification_currency_iso_code" do
         it "validates verification_currency_iso_code and updates the credit card " do
           customer = Braintree::Customer.create!
